function varargout = kalkulacka(varargin)
% KALKULACKA M-file for kalkulacka.fig
%      KALKULACKA, by itself, creates a new KALKULACKA or raises the existing
%      singleton*.
%
%      H = KALKULACKA returns the handle to a new KALKULACKA or the handle to
%      the existing singleton*.
%
%      KALKULACKA('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in KALKULACKA.M with the given input arguments.
%
%      KALKULACKA('Property','Value',...) creates a new KALKULACKA or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before kalkulacka_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to kalkulacka_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help kalkulacka

% Last Modified by GUIDE v2.5 09-Dec-2010 16:29:06

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @kalkulacka_OpeningFcn, ...
                   'gui_OutputFcn',  @kalkulacka_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before kalkulacka is made visible.
function kalkulacka_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to kalkulacka (see VARARGIN)

% Choose default command line output for kalkulacka
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes kalkulacka wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = kalkulacka_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double
input = str2num(get(hObject,'String'));

if (isempty(input))
    set(hObject,'String','0')
end

guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_Callback(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit2 as text
%        str2double(get(hObject,'String')) returns contents of edit2 as a double

input = str2num(get(hObject,'String'));

if (isempty(input))
    set(hObject,'String','0')
end

guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function edit2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%a,b jsou promenne datoveho string a je treba je prevest na datovy typ
%integer resp. number, aby se mohly secist
a = get(handles.edit1,'String');
b = get(handles.edit2,'String');
%priznaky jednotlivych radiobutton, u kterych hodnota value nastavena na 1
%rika, ze jsou aktivni, zjisteni a pristup ke grafickemu objektu jednoznace pomoci Tag
priznak1 = get(findobj('Tag','radiobutton1'),'Value');
priznak2 = get(findobj('Tag','radiobutton2'),'Value');
priznak3 = get(findobj('Tag','radiobutton3'),'Value');
%logika kalkulacky, vysledek ulozeny v promenne c je treba pred vypsanim
%konvertovat zpet na datovy typ String
if priznak1 == 1
    total = str2num(a) + str2num(b);
    c =num2str(total);
elseif priznak2 == 1
    total = str2num(a) - str2num(b);
    c =num2str(total);
elseif priznak3 == 1
    total = str2num(a) * str2num(b);
    c =num2str(total);  
else
    total = str2num(a) / str2num(b);
    c =num2str(total); 
end

set(handles.text6,'String',c)

guidata(hObject,handles);

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close all

